@@ -85,8 +85,14 @@ MenuStateLoadGame::MenuStateLoadGame(Program *program, MainMenu *mainMenu):
 	infoHeaderLabel.setFont3D(CoreData::getInstance().getMenuFontBig3D());
 	infoHeaderLabel.setText(lang.getString("SavegameInfo"));
 
+	versionWarningLabel.registerGraphicComponent(containerName,"versionWarningLabel");
+	versionWarningLabel.init(550, 350);
+	versionWarningLabel.setText("");
+	versionWarningLabel.setTextColor(Vec3f(1.0f,0.5f,0.5f));
+
+
 	infoTextLabel.registerGraphicComponent(containerName,"infoTextLabel");
-	infoTextLabel.init(550, 350);
+	infoTextLabel.init(550, 310);
 	infoTextLabel.setText("");
 
     abortButton.registerGraphicComponent(containerName,"abortButton");
@@ -302,10 +308,15 @@ void MenuStateLoadGame::mouseClick(int x, int y, MouseButton mouseButton){
 					if(fileExists(filename) == true) {
 						// Xerces is infinitely slower than rapidxml
 						xml_engine_parser_type engine_type = XML_RAPIDXML_ENGINE;
+
+#if defined(WANT_XERCES)
+
 						if(Config::getInstance().getBool("ForceXMLLoadGameUsingXerces","false") == true) {
 							engine_type = XML_XERCES_ENGINE;
 						}
-						// XmlTree	xmlTree(XML_XERCES_ENGINE);
+
+#endif
+
 						XmlTree	xmlTree(engine_type);
 
 						if(SystemFlags::VERBOSE_MODE_ENABLED) printf("Before load of XML\n");
@@ -332,25 +343,26 @@ void MenuStateLoadGame::mouseClick(int x, int y, MouseButton mouseButton){
 							if(gameVer != glestVersionString && checkVersionComptability(gameVer, glestVersionString) == false) {
 								char szBuf[8096]="";
 								snprintf(szBuf,8096,lang.getString("SavedGameBadVersion").c_str(),gameVer.c_str(),glestVersionString.c_str());
-								infoTextLabel.setText(szBuf);
+								versionWarningLabel.setText(szBuf);
 							}
 							else {
-								XmlNode *gameNode = rootNode->getChild("Game");
-								GameSettings newGameSettings;
-								newGameSettings.loadGame(gameNode);
-
-								char szBuf[8096]="";
-								snprintf(szBuf,8096,lang.getString("LoadSavedGameInfo").c_str(),
-										newGameSettings.getMap().c_str(),
-										newGameSettings.getTileset().c_str(),
-										newGameSettings.getTech().c_str(),
-										newGameSettings.getScenario().c_str(),
-										newGameSettings.getFactionCount(),
-										(newGameSettings.getThisFactionIndex() >= 0 &&
-										 newGameSettings.getThisFactionIndex() < newGameSettings.getFactionCount() ?
-										newGameSettings.getFactionTypeName(newGameSettings.getThisFactionIndex()).c_str() : ""));
-								infoTextLabel.setText(szBuf);
+								versionWarningLabel.setText("");
 							}
+							XmlNode *gameNode = rootNode->getChild("Game");
+							GameSettings newGameSettings;
+							newGameSettings.loadGame(gameNode);
+
+							char szBuf[8096]="";
+							snprintf(szBuf,8096,lang.getString("LoadSavedGameInfo").c_str(),
+									newGameSettings.getMap().c_str(),
+									newGameSettings.getTileset().c_str(),
+									newGameSettings.getTech().c_str(),
+									newGameSettings.getScenario().c_str(),
+									newGameSettings.getFactionCount(),
+									(newGameSettings.getThisFactionIndex() >= 0 &&
+									 newGameSettings.getThisFactionIndex() < newGameSettings.getFactionCount() ?
+									newGameSettings.getFactionTypeName(newGameSettings.getThisFactionIndex()).c_str() : ""));
+							infoTextLabel.setText(szBuf);
 						}
 						catch(const megaglest_runtime_error &ex) {
 							char szBuf[8096]="";
@@ -396,6 +408,8 @@ void MenuStateLoadGame::render() {
 	renderer.renderLabel(&savedGamesLabel);
 	renderer.renderLabel(&infoHeaderLabel);
 	renderer.renderLabel(&infoTextLabel);
+	if(versionWarningLabel.getText()!="")
+		renderer.renderLabel(&versionWarningLabel);
 
 	renderer.renderButton(&abortButton);
 	renderer.renderButton(&deleteButton);
@@ -429,7 +443,7 @@ void MenuStateLoadGame::render() {
 		renderer.renderMessageBox(&mainMessageBox);
 	}
 
-	renderer.renderConsole(&console,false,false);
+	renderer.renderConsole(&console);
 	if(program != NULL) program->renderProgramMsgBox();
 }
 
