@@ -227,7 +227,7 @@ bool EndsWith(const string &str, const string& key);
 
 void endPathWithSlash(string &path, bool requireOSSlash=false);
 void trimPathWithStartingSlash(string &path);
-void updatePathClimbingParts(string &path);
+void updatePathClimbingParts(string &path,bool processPreviousDirTokenCheck=true);
 string formatPath(string path);
 
 string replaceAllHTMLEntities(string& context);
