@@ -28,18 +28,11 @@ GraphicsFactory *FactoryRepository::getGraphicsFactory(const string &name){
 	if(name == "OpenGL"){
 		return &graphicsFactoryGl;
 	}
-	else if(name == "OpenGL2"){
-		return &graphicsFactoryGl2;
-	}
 
 	throw megaglest_runtime_error("Unknown graphics factory: [" + name + "]");
 }
 
 SoundFactory *FactoryRepository::getSoundFactory(const string &name){
-	// deprecated as of 3.6.1
-	//if(name == "DirectSound8"){
-	//	return &soundFactoryDs8;
-	//}
 	if(name == "OpenAL") {
 		return &soundFactoryOpenAL;
 	}
